@@ -100,7 +100,7 @@ find_statistic <- function(x, ...) {
     "mmrm_tmb",
     "nlmerMod", "nlrq", "nls",
     "ols", "orcutt",
-    "pb1", "pb2", "polr",
+    "pb1", "pb2", "polr", "phylolm",
     "rlm", "rms", "rlmerMod", "rq", "rqs", "rqss",
     "selection", "speedlm", "spml", "summary.lm", "svyglm", "svyolr", "systemfit",
     "truncreg",
@@ -125,11 +125,11 @@ find_statistic <- function(x, ...) {
     "hurdle",
     "lavaan", "loggammacenslmrob", "logitmfx", "logitor", "logitr", "LORgee", "lrm",
     "margins", "marginaleffects", "marginaleffects.summary", "metaplus", "mixor",
-    "MixMod", "mjoint", "mle", "mle2", "mlogit", "mclogit", "mmclogit", "mvmeta",
-    "mvord",
-    "negbin", "negbinmfx", "negbinirr", "nlreg",
+    "MixMod", "mjoint", "mle", "mle2", "mlogit", "mblogit", "mclogit", "mmclogit",
+    "mvmeta", "mvord",
+    "negbin", "negbinmfx", "negbinirr", "nlreg", "nestedLogit",
     "objectiveML", "orm",
-    "poissonmfx", "poissonirr", "psm", "probitmfx", "pgmm",
+    "poissonmfx", "poissonirr", "psm", "probitmfx", "pgmm", "phyloglm",
     "qr", "QRNLMM", "QRLMM",
     "Rchoice", "riskRegression", "robmixglm", "rma", "rma.mv", "rma.uni", "rrvglm",
     "Sarlm", "sem", "SemiParBIV", "slm", "slopes", "survreg", "svy_vglm",
@@ -174,7 +174,6 @@ find_statistic <- function(x, ...) {
       "bam", "bigglm",
       "cgam", "cgamm",
       "eglm", "emmGrid", "emm_list",
-      "fixest",
       "gam", "glm", "Glm", "glmc", "glmerMod", "glmRob", "glmrob",
       "pseudoglm",
       "scam",
@@ -191,7 +190,7 @@ find_statistic <- function(x, ...) {
 
   # pattern finding ----------------------------------------------------------
 
-  unclear.mods <- "plm"
+  unclear.mods <- c("plm", "fixest")
 
   if (inherits(x, "glht")) {
     if (x$df == 0) {
@@ -290,6 +289,17 @@ find_statistic <- function(x, ...) {
   # ambiguous cases -----------------------------------------------------------
 
   if (model_class %in% unclear.mods) {
+    # special handling for fixest, see
+    # https://github.com/easystats/parameters/issues/892#issuecomment-1712645841
+    # and https://github.com/lrberge/fixest/blob/c14c55917897478d996f80bd3392d2e7355b1f29/R/ESTIMATION_FUNS.R#L2903
+    if (model_class == "fixest") {
+      if (m_info$family %in% c("binomial", "poisson")) {
+        return("z-statistic")
+      } else {
+        return("t-statistic")
+      }
+    }
+
     col_names <- colnames(as.data.frame(summary(x)$coefficients))
 
     t_names <- c(
