@@ -78,7 +78,7 @@ get_weights.default <- function(x, na_rm = FALSE, null_as_ones = FALSE, ...) {
 
   # if all weights are 1, set return value to NULL,
   # unless the weights were explicitly set in the model call
-  if (!is.null(w) && all(w == 1L) && is.null(weight_vars)) {
+  if (!is.null(w) && isTRUE(all(w[!is.na(w)] == 1L)) && is.null(weight_vars)) {
     w <- NULL
   }
 
