@@ -69,6 +69,9 @@ link_function.lm <- function(x, ...) {
   stats::gaussian(link = "identity")$linkfun
 }
 
+#' @export
+link_function.phylolm <- link_function.lm
+
 #' @export
 link_function.lme <- link_function.lm
 
@@ -183,6 +186,11 @@ link_function.brglm <- link_function.default
 #' @export
 link_function.cgam <- link_function.default
 
+#' @export
+link_function.nestedLogit <- function(x, ...) {
+  stats::make.link(link = "logit")$linkfun
+}
+
 
 # Logit link ------------------------
 
@@ -252,6 +260,18 @@ link_function.riskRegression <- link_function.multinom
 link_function.comprisk <- link_function.multinom
 
 
+# Phylo glm ------------------------
+
+#' @export
+link_inverse.phyloglm <- function(x, ...) {
+  if (startsWith(x$method, "logistic")) {
+    stats::make.link("logit")$linkfun
+  } else {
+    stats::poisson(link = "log")$linkfun
+  }
+}
+
+
 # Probit link ------------------------
 
 #' @export
